[Scummvm-cvs-logs] SF.net SVN: scummvm:[47179] scummvm/trunk

fingolfin at users.sourceforge.net fingolfin at users.sourceforge.net
Fri Jan 8 23:06:05 CET 2010


Revision: 47179
          http://scummvm.svn.sourceforge.net/scummvm/?rev=47179&view=rev
Author:   fingolfin
Date:     2010-01-08 22:06:04 +0000 (Fri, 08 Jan 2010)

Log Message:
-----------
Rename QueuedAudioStream to QueuingAudioStream

Modified Paths:
--------------
    scummvm/trunk/engines/made/pmvplayer.cpp
    scummvm/trunk/engines/made/pmvplayer.h
    scummvm/trunk/engines/mohawk/video/qt_player.cpp
    scummvm/trunk/engines/mohawk/video/qt_player.h
    scummvm/trunk/engines/tinsel/bmv.cpp
    scummvm/trunk/engines/tinsel/bmv.h
    scummvm/trunk/graphics/video/avi_decoder.cpp
    scummvm/trunk/graphics/video/avi_decoder.h
    scummvm/trunk/graphics/video/coktelvideo/coktelvideo.cpp
    scummvm/trunk/graphics/video/coktelvideo/coktelvideo.h
    scummvm/trunk/graphics/video/smk_decoder.cpp
    scummvm/trunk/graphics/video/smk_decoder.h
    scummvm/trunk/sound/audiostream.cpp
    scummvm/trunk/sound/audiostream.h

Modified: scummvm/trunk/engines/made/pmvplayer.cpp
===================================================================
--- scummvm/trunk/engines/made/pmvplayer.cpp	2010-01-08 22:05:12 UTC (rev 47178)
+++ scummvm/trunk/engines/made/pmvplayer.cpp	2010-01-08 22:06:04 UTC (rev 47179)
@@ -102,7 +102,7 @@
 	// TODO: Sound can still be a little choppy. A bug in the decoder or -
 	// perhaps more likely - do we have to implement double buffering to
 	// get it to work well?
-	_audioStream = Audio::makeQueuedAudioStream(soundFreq, false);
+	_audioStream = Audio::makeQueuingAudioStream(soundFreq, false);
 
 	while (!_vm->shouldQuit() && !_aborted && !_fd->eos() && frameNumber < frameCount) {
 

Modified: scummvm/trunk/engines/made/pmvplayer.h
===================================================================
--- scummvm/trunk/engines/made/pmvplayer.h	2010-01-08 22:05:12 UTC (rev 47178)
+++ scummvm/trunk/engines/made/pmvplayer.h	2010-01-08 22:06:04 UTC (rev 47179)
@@ -50,7 +50,7 @@
 	MadeEngine *_vm;
 	Audio::Mixer *_mixer;
 	Common::File *_fd;
-	Audio::QueuedAudioStream *_audioStream;
+	Audio::QueuingAudioStream *_audioStream;
 	Audio::SoundHandle _audioStreamHandle;
 	byte _paletteRGB[768];
 	Graphics::Surface *_surface;

Modified: scummvm/trunk/engines/mohawk/video/qt_player.cpp
===================================================================
--- scummvm/trunk/engines/mohawk/video/qt_player.cpp	2010-01-08 22:05:12 UTC (rev 47178)
+++ scummvm/trunk/engines/mohawk/video/qt_player.cpp	2010-01-08 22:06:04 UTC (rev 47179)
@@ -148,7 +148,7 @@
 	stopAudio();
 	if (_audioStreamIndex >= 0) {
 		_curAudioChunk = 0;
-		_audStream = Audio::makeQueuedAudioStream(_streams[_audioStreamIndex]->sample_rate, _streams[_audioStreamIndex]->channels == 2);
+		_audStream = Audio::makeQueuingAudioStream(_streams[_audioStreamIndex]->sample_rate, _streams[_audioStreamIndex]->channels == 2);
 	}
 	startAudio();
 }
@@ -304,7 +304,7 @@
 	}
 	
 	if (_audioStreamIndex >= 0 && checkAudioCodecSupport(_streams[_audioStreamIndex]->codec_tag)) {
-		_audStream = Audio::makeQueuedAudioStream(_streams[_audioStreamIndex]->sample_rate, _streams[_audioStreamIndex]->channels == 2);
+		_audStream = Audio::makeQueuingAudioStream(_streams[_audioStreamIndex]->sample_rate, _streams[_audioStreamIndex]->channels == 2);
 		_curAudioChunk = 0;
 	
 		// Make sure the bits per sample transfers to the sample size

Modified: scummvm/trunk/engines/mohawk/video/qt_player.h
===================================================================
--- scummvm/trunk/engines/mohawk/video/qt_player.h	2010-01-08 22:05:12 UTC (rev 47178)
+++ scummvm/trunk/engines/mohawk/video/qt_player.h	2010-01-08 22:06:04 UTC (rev 47179)
@@ -246,7 +246,7 @@
 	void resetInternal();
 	uint32 getFrameDuration();
 
-	Audio::QueuedAudioStream *_audStream;
+	Audio::QueuingAudioStream *_audStream;
 	int8 _videoStreamIndex;
 	int8 _audioStreamIndex;
 	uint _curAudioChunk;

Modified: scummvm/trunk/engines/tinsel/bmv.cpp
===================================================================
--- scummvm/trunk/engines/tinsel/bmv.cpp	2010-01-08 22:05:12 UTC (rev 47178)
+++ scummvm/trunk/engines/tinsel/bmv.cpp	2010-01-08 22:06:04 UTC (rev 47179)
@@ -423,7 +423,7 @@
 }
 
 void BMVPlayer::InitialiseMovieSound() {
-	_audioStream = Audio::makeQueuedAudioStream(22050, true);
+	_audioStream = Audio::makeQueuingAudioStream(22050, true);
 	audioStarted = false;
 }
 

Modified: scummvm/trunk/engines/tinsel/bmv.h
===================================================================
--- scummvm/trunk/engines/tinsel/bmv.h	2010-01-08 22:05:12 UTC (rev 47178)
+++ scummvm/trunk/engines/tinsel/bmv.h	2010-01-08 22:06:04 UTC (rev 47179)
@@ -113,7 +113,7 @@
 
 	bool audioStarted;
 
-	Audio::QueuedAudioStream *_audioStream;
+	Audio::QueuingAudioStream *_audioStream;
 	Audio::SoundHandle _audioHandle;
 
 	int nextMaintain;

Modified: scummvm/trunk/graphics/video/avi_decoder.cpp
===================================================================
--- scummvm/trunk/graphics/video/avi_decoder.cpp	2010-01-08 22:05:12 UTC (rev 47178)
+++ scummvm/trunk/graphics/video/avi_decoder.cpp	2010-01-08 22:06:04 UTC (rev 47179)
@@ -431,10 +431,10 @@
 	return NULL;
 }
 
-Audio::QueuedAudioStream *AviDecoder::createAudioStream() {
+Audio::QueuingAudioStream *AviDecoder::createAudioStream() {
 
 	if (_wvInfo.tag == AVI_WAVE_FORMAT_PCM) {
-		return Audio::makeQueuedAudioStream(AUDIO_RATE, false);
+		return Audio::makeQueuingAudioStream(AUDIO_RATE, false);
 	}
 	
 	if (_wvInfo.tag != 0) // No sound

Modified: scummvm/trunk/graphics/video/avi_decoder.h
===================================================================
--- scummvm/trunk/graphics/video/avi_decoder.h	2010-01-08 22:05:12 UTC (rev 47178)
+++ scummvm/trunk/graphics/video/avi_decoder.h	2010-01-08 22:06:04 UTC (rev 47179)
@@ -216,8 +216,8 @@
 	void handlePalChange();
 	
 	Audio::SoundHandle *_audHandle;
-	Audio::QueuedAudioStream *_audStream;
-	Audio::QueuedAudioStream *createAudioStream();
+	Audio::QueuingAudioStream *_audStream;
+	Audio::QueuingAudioStream *createAudioStream();
 
 	// Helper functions
 	static byte char2num(char c);

Modified: scummvm/trunk/graphics/video/coktelvideo/coktelvideo.cpp
===================================================================
--- scummvm/trunk/graphics/video/coktelvideo/coktelvideo.h	2010-01-08 22:05:12 UTC (rev 47178)
+++ scummvm/trunk/graphics/video/coktelvideo/coktelvideo.h	2010-01-08 22:06:04 UTC (rev 47179)
@@ -341,7 +341,7 @@
 	uint8  _soundStage; // (0: no sound, 1: loaded, 2: playing)
 	uint32 _skipFrames;
 
-	Audio::QueuedAudioStream *_audioStream;
+	Audio::QueuingAudioStream *_audioStream;
 	Audio::SoundHandle _audioHandle;
 
 	// Current video state

Modified: scummvm/trunk/graphics/video/smk_decoder.cpp
===================================================================
--- scummvm/trunk/graphics/video/smk_decoder.h	2010-01-08 22:05:12 UTC (rev 47178)
+++ scummvm/trunk/graphics/video/smk_decoder.h	2010-01-08 22:06:04 UTC (rev 47179)
@@ -30,7 +30,7 @@
 #include "sound/mixer.h"
 
 namespace Audio {
-	class QueuedAudioStream;
+	class QueuingAudioStream;
 }
 
 namespace Graphics {
@@ -115,7 +115,7 @@
 	Audio::Mixer::SoundType _soundType;
 	Audio::Mixer *_mixer;
 	bool _audioStarted;
-	Audio::QueuedAudioStream *_audioStream;
+	Audio::QueuingAudioStream *_audioStream;
 	Audio::SoundHandle _audioHandle;
 
 	BigHuffmanTree *_MMapTree;

Modified: scummvm/trunk/sound/audiostream.cpp
===================================================================
--- scummvm/trunk/graphics/video/coktelvideo/coktelvideo.cpp	2010-01-08 22:05:12 UTC (rev 47178)
+++ scummvm/trunk/graphics/video/coktelvideo/coktelvideo.cpp	2010-01-08 22:06:04 UTC (rev 47179)
@@ -201,7 +201,7 @@
 		_soundStage = 1;
 		_hasSound   = true;
 
-		_audioStream = Audio::makeQueuedAudioStream(_soundFreq, false);
+		_audioStream = Audio::makeQueuingAudioStream(_soundFreq, false);
 	} else
 		_frameLength = 1000 / _frameRate;
 
@@ -1276,7 +1276,7 @@
 
 	_soundStage = 1;
 
-	_audioStream = Audio::makeQueuedAudioStream(_soundFreq, _soundStereo != 0);
+	_audioStream = Audio::makeQueuingAudioStream(_soundFreq, _soundStereo != 0);
 
 	return true;
 }
@@ -1562,9 +1562,9 @@
 		// FIXME: This code didn't check the stereo flag at all and always generated
 		// mono data. Is that on purpose? If so, just remove this comment.
 		// If it was by accident, remove the assert and replace "false" in the call
 		// to makeQueuedAudioStream() below by "_soundStereo > 0".
 		assert(_soundStereo == 0);
-		_audioStream = Audio::makeQueuedAudioStream(_soundFreq, false);
+		_audioStream = Audio::makeQueuingAudioStream(_soundFreq, false);
 	}
 
 	// Seek
@@ -1562,9 +1562,9 @@
 		// mono data. Is that on purpose? If so, just remove this comment.
 		// If it was by accident, remove the assert and replace "false" in the call
-		// to makeQueuedAudioStream() below by "_soundStereo > 0".
+		// to makeQueuingAudioStream() below by "_soundStereo > 0".
 		assert(_soundStereo == 0);

Modified: scummvm/trunk/graphics/video/coktelvideo/coktelvideo.h
===================================================================
--- scummvm/trunk/graphics/video/smk_decoder.cpp	2010-01-08 22:05:12 UTC (rev 47178)
+++ scummvm/trunk/graphics/video/smk_decoder.cpp	2010-01-08 22:06:04 UTC (rev 47179)
@@ -465,7 +465,7 @@
 		_header.audioInfo[i].sampleRate = audioInfo & 0xFFFFFF;
 
 		if (_header.audioInfo[i].hasAudio && i == 0) {
-			_audioStream = Audio::makeQueuedAudioStream(_header.audioInfo[0].sampleRate, _header.audioInfo[0].isStereo);
+			_audioStream = Audio::makeQueuingAudioStream(_header.audioInfo[0].sampleRate, _header.audioInfo[0].isStereo);
 		}
 	}
 
@@ -577,7 +577,7 @@
 					flags = flags | Audio::Mixer::FLAG_STEREO;
 
 				_audioStream->queueBuffer(soundBuffer, chunkSize, flags);
 				// The sound buffer will be deleted by QueuedAudioStream
 			}
 
 			if (!_audioStarted) {
@@ -831,7 +831,7 @@
 	if (_header.audioInfo[0].isStereo)
 		flags = flags | Audio::Mixer::FLAG_STEREO;
 	_audioStream->queueBuffer(unpackedBuffer, unpackedSize, flags);
 	// unpackedBuffer will be deleted by QueuedAudioStream
 }
 
 void SmackerDecoder::unpackPalette() {
@@ -577,7 +577,7 @@
 
 				_audioStream->queueBuffer(soundBuffer, chunkSize, flags);
-				// The sound buffer will be deleted by QueuedAudioStream
+				// The sound buffer will be deleted by QueuingAudioStream
 			}
 
@@ -831,7 +831,7 @@
 		flags = flags | Audio::Mixer::FLAG_STEREO;
 	_audioStream->queueBuffer(unpackedBuffer, unpackedSize, flags);
-	// unpackedBuffer will be deleted by QueuedAudioStream
+	// unpackedBuffer will be deleted by QueuingAudioStream
 }
 

Modified: scummvm/trunk/graphics/video/smk_decoder.h
===================================================================
--- scummvm/trunk/sound/audiostream.cpp	2010-01-08 22:05:12 UTC (rev 47178)
+++ scummvm/trunk/sound/audiostream.cpp	2010-01-08 22:06:04 UTC (rev 47179)
@@ -769,7 +769,7 @@
 #pragma mark -
 
 
-class QueuedAudioStreamImpl : public QueuedAudioStream {
+class QueuingAudioStreamImpl : public QueuingAudioStream {
 private:
 	/**
 	 * We queue a number of (pointers to) audio stream objects.
@@ -813,9 +813,9 @@
 	Common::Queue<StreamHolder> _queue;
 
 public:
-	QueuedAudioStreamImpl(int rate, bool stereo)
+	QueuingAudioStreamImpl(int rate, bool stereo)
 		: _rate(rate), _stereo(stereo), _finished(false) {}
-	~QueuedAudioStreamImpl();
+	~QueuingAudioStreamImpl();
 
 	// Implement the AudioStream API
 	virtual int readBuffer(int16 *buffer, const int numSamples);
@@ -827,7 +827,7 @@
 	}
 	virtual bool endOfStream() const { return _finished; }
 
 	// Implement the QueuedAudioStream API
 	virtual void queueAudioStream(AudioStream *stream, bool disposeAfterUse);
 	virtual void finish() { _finished = true; }
 
@@ -837,7 +837,7 @@
 	}
 };
 
-QueuedAudioStreamImpl::~QueuedAudioStreamImpl() {
+QueuingAudioStreamImpl::~QueuingAudioStreamImpl() {
 	while (!_queue.empty()) {
 		StreamHolder tmp = _queue.pop();
 		if (tmp._disposeAfterUse)
@@ -845,15 +845,15 @@
 	}
 }
 
-void QueuedAudioStreamImpl::queueAudioStream(AudioStream *stream, bool disposeAfterUse) {
+void QueuingAudioStreamImpl::queueAudioStream(AudioStream *stream, bool disposeAfterUse) {
 	if ((stream->getRate() != getRate()) || (stream->isStereo() != isStereo()))
-		error("QueuedAudioStreamImpl::queueAudioStream: stream has mismatched parameters");
+		error("QueuingAudioStreamImpl::queueAudioStream: stream has mismatched parameters");
 
 	Common::StackLock lock(_mutex);
 	_queue.push(StreamHolder(stream, disposeAfterUse));
 }
 
-int QueuedAudioStreamImpl::readBuffer(int16 *buffer, const int numSamples) {
+int QueuingAudioStreamImpl::readBuffer(int16 *buffer, const int numSamples) {
 	Common::StackLock lock(_mutex);
 	int samplesDecoded = 0;
 
@@ -873,8 +873,8 @@
 
 
 
-QueuedAudioStream *makeQueuedAudioStream(int rate, bool stereo) {
-	return new QueuedAudioStreamImpl(rate, stereo);
+QueuingAudioStream *makeQueuingAudioStream(int rate, bool stereo) {
+	return new QueuingAudioStreamImpl(rate, stereo);
 }
 
 
@@ -827,7 +827,7 @@
 	virtual bool endOfStream() const { return _finished; }
 
-	// Implement the QueuedAudioStream API
+	// Implement the QueuingAudioStream API
 	virtual void queueAudioStream(AudioStream *stream, bool disposeAfterUse);
 	virtual void finish() { _finished = true; }

Modified: scummvm/trunk/sound/audiostream.h
===================================================================
--- scummvm/trunk/sound/audiostream.h	2010-01-08 22:05:12 UTC (rev 47178)
+++ scummvm/trunk/sound/audiostream.h	2010-01-08 22:06:04 UTC (rev 47179)
@@ -320,7 +320,7 @@
 AppendableAudioStream *makeAppendableAudioStream(int rate, byte flags);
 
 
-class QueuedAudioStream : public Audio::AudioStream {
+class QueuingAudioStream : public Audio::AudioStream {
 public:
 
 	/**
@@ -359,9 +359,9 @@
 };
 
 /**
  * Factory function for an QueuedAudioStream.
  */
-QueuedAudioStream *makeQueuedAudioStream(int rate, bool stereo);
+QueuingAudioStream *makeQueuingAudioStream(int rate, bool stereo);
 
 
 /**
@@ -359,9 +359,9 @@
 
 /**
- * Factory function for an QueuedAudioStream.
+ * Factory function for an QueuingAudioStream.
  */


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list